@@ -672,13 +672,6 @@ dojo.requireLocalization("dijit", "loading");
 			// called.  This saves us an extra call to _resize(), which can
 			// get kind of heavy.
 
-			// fixes #11101, should ignore resize when in autoheight mode(IE) to avoid a deadlock
-			// e.g when an autoheight editable grid put in dijit.form.Form or other similar containers,
-			// grid switch to editing mode --> grid height change --> From height change
-			// ---> Form call grid.resize() ---> grid height change  --> deaklock
-			if(dojo.isIE && !changeSize && !resultSize && this._autoHeight){
-				return;
-			}
 			this._pendingChangeSize = changeSize;
 			this._pendingResultSize = resultSize;
 			this.sizeChange();
@@ -908,7 +901,7 @@ dojo.requireLocalization("dijit", "loading");
 		// update
 		defaultUpdate: function(){
 			// note: initial update calls render and subsequently this function.
-			if(!this.domNode){return;}
+			if(!this.domNode || this.edit._noUpdate){return;}
 			if(this.updating){
 				this.invalidated.all = true;
 				return;
