@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FrontTest.php 24594 2012-01-05 21:27:01Z matthew $
+ * @version    $Id: FrontTest.php 25217 2013-01-11 11:14:17Z frosch $
  */
 
 // Call Zend_Controller_FrontTest::main() if this source file is executed directly.
@@ -610,9 +610,11 @@ class Zend_Controller_FrontTest extends PHPUnit_Framework_TestCase
         try {
             $this->_controller->addModuleDirectory($moduleDir);
             $this->fail('Exception expected but not thrown');
-        }catch(Exception $e){
-            $this->assertType('Zend_Exception',$e);
-            $this->assertRegExp('/Directory \w+ not readable/',$e->getMessage());
+        } catch (Exception $e) {
+            $this->assertTrue($e instanceof Zend_Exception);
+            $this->assertRegExp(
+                '/Directory \w+ not readable/', $e->getMessage()
+            );
         }
     }
 
