@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FileTest.php 24594 2012-01-05 21:27:01Z matthew $
+ * @version    $Id: FileTest.php 25225 2013-01-17 15:59:16Z frosch $
  */
 
 // Call Zend_Form_Element_FileTest::main() if this source file is executed directly.
@@ -491,6 +491,48 @@ class Zend_Form_Element_FileTest extends PHPUnit_Framework_TestCase
     {
         $this->assertSame($this->element, $this->element->loadDefaultDecorators());
     }
+    
+    /**
+     * @group ZF-12173
+     */
+    public function testElementShouldAllowAdapterWithBackslahes()
+    {
+        if (version_compare(PHP_VERSION, '5.3.0', '<')) {
+            $this->markTestSkipped(
+                __CLASS__ . '::' . __METHOD__ . ' requires PHP 5.3.0 or greater'
+            );
+            return;
+        }
+        $this->element->addPrefixPath(
+            'Zend\Form\Element\FileTest\Adapter',
+            dirname(__FILE__) . '/_files/TransferAdapter',
+            'transfer_adapter'
+        );
+        $this->element->setTransferAdapter('Bar');
+        $test = $this->element->getTransferAdapter();
+        $this->assertTrue(
+            $test instanceof \Zend\Form\Element\FileTest\Adapter\Bar
+        );
+    }
+
+    /**
+     * @group ZF-12210
+     */
+    public function testAutoInsertNotEmptyValidator()
+    {
+        $this->testElementShouldAllowSpecifyingAdapterUsingConcreteInstance();
+        $this->element->setRequired(true);
+
+        // Test before validation
+        $this->assertNull($this->element->getValidator('NotEmpty'));
+
+        // Test after validation
+        $this->element->isValid('foo.jpg');
+
+        $this->assertTrue(
+            $this->element->getValidator('NotEmpty') instanceof Zend_Validate_NotEmpty
+        );
+    }
 }
 
 class Zend_Form_Element_FileTest_MockAdapter extends Zend_File_Transfer_Adapter_Abstract
