@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: OfflineTest.php 24594 2012-01-05 21:27:01Z matthew $
+ * @version    $Id: OfflineTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 /**
@@ -615,7 +615,8 @@ class Zend_Ldap_Node_OfflineTest extends Zend_Ldap_TestCase
         );
 
         $node = Zend_Ldap_Node::fromArray($data, true);
-        $this->assertEmpty($node->getChangedData());
+        $changedData = $node->getChangedData();
+        $this->assertTrue(empty($changedData));
     }
 
 	/**
