@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: LogTest.php 24594 2012-01-05 21:27:01Z matthew $
+ * @version    $Id: LogTest.php 24703 2012-03-29 09:52:39Z andries $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -523,6 +523,31 @@ class Zend_Log_LogTest extends PHPUnit_Framework_TestCase
 
         $this->assertEquals('c', $logger->getTimestampFormat());
     }
+
+    public function testFactorySupportsPHP53Namespaces()
+    {
+        if (version_compare(PHP_VERSION, '5.3.0') < 0) {
+            $this->markTestSkipped('PHP < 5.3.0 does not support namespaces');
+        }
+
+        // preload namespaced class from custom path
+        Zend_Loader::loadClass('\Zfns\Writer', array(dirname(__FILE__) . '/_files'));
+
+        try {
+            $config = array(
+                'mine' => array(
+                    'writerName'      => 'Writer',
+                    'writerNamespace' => '\Zfns\\',
+                )
+            );
+
+            $logger = Zend_log::factory($config);
+            $logger->info('this is a test');
+
+        } catch (Zend_Log_Exception $e) {
+            $this->fail('Unable to load namespaced class');
+        }
+    }
 }
 
 class Zend_Log_Writer_NotExtendedWriterAbstract implements Zend_Log_FactoryInterface
@@ -553,4 +578,4 @@ class Custom_Formatter_Mock extends Zend_Log_Formatter_Abstract
 
 if (PHPUnit_MAIN_METHOD == 'Zend_Log_LogTest::main') {
     Zend_Log_LogTest::main();
-}
\ No newline at end of file
+}
