@@ -17,13 +17,14 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MvcTest.php 24594 2012-01-05 21:27:01Z matthew $
+ * @version    $Id: MvcTest.php 25251 2013-02-06 10:19:45Z frosch $
  */
 
 require_once 'Zend/Navigation/Page/Mvc.php';
 require_once 'Zend/Controller/Request/Http.php';
 require_once 'Zend/Controller/Router/Route.php';
 require_once 'Zend/Controller/Router/Route/Regex.php';
+require_once 'Zend/Controller/Router/Route/Chain.php';
 
 /**
  * Tests the class Zend_Navigation_Page_Mvc
@@ -267,6 +268,34 @@ class Zend_Navigation_Page_MvcTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(true, $page->isActive());
     }
 
+    /**
+     * @group ZF-11664
+     */
+    public function testIsActiveWithoutAndWithRecursiveOption()
+    {
+        // Parent
+        $page = new Zend_Navigation_Page_Mvc(array(
+            'controller' => 'index',
+            'action'     => 'index',
+        ));
+
+        // Child
+        $page->addPage(new Zend_Navigation_Page_Mvc(array(
+            'controller' => 'index',
+            'action'     => 'foo',
+        )));
+
+        // Front controller
+        $this->_front->getRequest()->setParams(array(
+            'controller' => 'index',
+            'action'     => 'foo'
+        ));
+
+        $this->assertFalse($page->isActive());
+
+        $this->assertTrue($page->isActive(true));
+    }
+
     public function testActionAndControllerAccessors()
     {
         $page = new Zend_Navigation_Page_Mvc(array(
@@ -378,6 +407,110 @@ class Zend_Navigation_Page_MvcTest extends PHPUnit_Framework_TestCase
         $page->setParams(array());
         $this->assertEquals(array(), $page->getParams());
     }
+    
+    /**
+     * @group ZF-10727
+     */
+    public function testSetAndGetParam()
+    {
+        $page = new Zend_Navigation_Page_Mvc(array(
+            'label' => 'foo',
+            'action' => 'index',
+            'controller' => 'index'
+        ));
+        
+        $page->setParam('foo', 'bar');
+        $this->assertEquals('bar', $page->getParam('foo'));
+        
+        // Check type conversion
+        $page->setParam(null, null);
+        $this->assertEquals(null, $page->getParam('null'));
+    }
+    
+    /**
+     * @group ZF-10727
+     */
+    public function testAddParams()
+    {
+        $page = new Zend_Navigation_Page_Mvc(array(
+            'label' => 'foo',
+            'action' => 'index',
+            'controller' => 'index'
+        ));
+        
+        $params = array('foo' => 'bar', 'baz' => 'bat');
+        
+        $page->addParams($params);
+        $this->assertEquals($params, $page->getParams());
+        
+        $params2 = array('qux' => 'foobar');
+        
+        $page->addParams($params2);
+        $this->assertEquals(array_merge($params, $params2), $page->getParams());
+    }
+    
+    /**
+     * @group ZF-10727
+     */
+    public function testRemoveParam()
+    {
+        $page = new Zend_Navigation_Page_Mvc(array(
+            'label' => 'foo',
+            'action' => 'index',
+            'controller' => 'index'
+        ));
+        
+        $params = array('foo' => 'bar', 'baz' => 'bat');
+        
+        $page->setParams($params);
+        $page->removeParam('foo');
+        
+        $this->assertEquals(array('baz' => 'bat'), $page->getParams());
+        
+        $this->assertNull($page->getParam('foo'));
+    }
+    
+    /**
+     * @group ZF-10727
+     */
+    public function testClearParams()
+    {
+        $page = new Zend_Navigation_Page_Mvc(array(
+            'label' => 'foo',
+            'action' => 'index',
+            'controller' => 'index'
+        ));
+        
+        $params = array('foo' => 'bar', 'baz' => 'bat');
+        
+        $page->setParams($params);
+        $page->clearParams();
+        
+        $this->assertEquals(array(), $page->getParams());
+    }
+
+    /**
+     * @group ZF-11664
+     */
+    public function testSetActiveAndIsActive()
+    {
+        // Page
+        $page = new Zend_Navigation_Page_Mvc(array(
+            'controller' => 'foo',
+            'action'     => 'bar',
+        ));
+
+        // Front controller
+        $this->_front->getRequest()->setParams(array(
+            'controller' => 'foo',
+            'action'     => 'bar'
+        ));
+
+        $this->assertTrue($page->isActive());
+
+        $page->setActive(false);
+        $this->assertFalse($page->isActive());
+    }
 
     /**
      * @group ZF-10465
@@ -427,25 +560,105 @@ class Zend_Navigation_Page_MvcTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('/pagexy/subpage.html', $page->getHref());
     }
 
+    /**
+     * @group ZF-7794
+     */
+    public function testSetScheme()
+    {
+        $page = new Zend_Navigation_Page_Mvc();
+        $page->setScheme('https');
+
+        $this->assertEquals('https', $page->getScheme());
+    }
+
+    /**
+     * @group ZF-7794
+     */
+    public function testOptionScheme()
+    {
+        $page = new Zend_Navigation_Page_Mvc(
+            array(
+                 'scheme' => 'https',
+            )
+        );
+
+        $this->assertEquals('https', $page->getScheme());
+    }
+
+    /**
+     * @group ZF-7794
+     */
+    public function testHrefGeneratedWithScheme()
+    {
+        $page = new Zend_Navigation_Page_Mvc(array(
+            'controller' => 'foo',
+            'action'     => 'bar',
+            'scheme'     => 'https',
+        ));
+
+        $_SERVER['HTTP_HOST'] = 'foobar.example.com';
+
+        $this->assertEquals(
+            'https://foobar.example.com/foo/bar',
+            $page->getHref()
+        );
+    }
+
+    /**
+     * @group ZF-7794
+     */
+    public function testHrefGeneratedWithSchemeIsRouteAware()
+    {
+        $page = new Zend_Navigation_Page_Mvc(array(
+            'action'     => 'myaction',
+            'controller' => 'mycontroller',
+            'route'      => 'myroute',
+            'params'     => array(
+                'page' => 1337,
+            ),
+            'scheme'     => 'https',
+        ));
+
+        $this->_front->getRouter()->addRoute(
+            'myroute',
+            new Zend_Controller_Router_Route(
+                'lolcat/:action/:page',
+                array(
+                    'module'     => 'default',
+                    'controller' => 'foobar',
+                    'action'     => 'bazbat',
+                    'page'       => 1,
+                )
+            )
+        );
+
+        $_SERVER['HTTP_HOST'] = 'foobar.example.com';
+
+        $this->assertEquals(
+            'https://foobar.example.com/lolcat/myaction/1337',
+            $page->getHref()
+        );
+    }
+
     public function testToArrayMethod()
     {
         $options = array(
-            'label' => 'foo',
-            'action' => 'index',
+            'label'      => 'foo',
+            'action'     => 'index',
             'controller' => 'index',
-            'module' => 'test',
-            'fragment' => 'bar',
-            'id' => 'my-id',
-            'class' => 'my-class',
-            'title' => 'my-title',
-            'target' => 'my-target',
-            'order' => 100,
-            'active' => true,
-            'visible' => false,
+            'module'     => 'test',
+            'fragment'   => 'bar',
+            'id'         => 'my-id',
+            'class'      => 'my-class',
+            'title'      => 'my-title',
+            'target'     => 'my-target',
+            'order'      => 100,
+            'active'     => true,
+            'visible'    => false,
             'encodeUrl'  => false,
-
-            'foo' => 'bar',
-            'meaning' => 42
+            'scheme'     => 'https',
+            'foo'        => 'bar',
+            'meaning'    => 42
         );
 
         $page = new Zend_Navigation_Page_Mvc($options);
@@ -453,13 +666,15 @@ class Zend_Navigation_Page_MvcTest extends PHPUnit_Framework_TestCase
         $toArray = $page->toArray();
 
         $options['reset_params'] = true;
-        $options['route'] = null;
-        $options['params'] = array();
-        $options['rel'] = array();
-        $options['rev'] = array();
+        $options['route']        = null;
+        $options['params']       = array();
+        $options['rel']          = array();
+        $options['rev']          = array();
 
-        $this->assertEquals(array(),
-            array_diff_assoc($options, $page->toArray()));
+        $this->assertEquals(
+            array(),
+            array_diff_assoc($options, $page->toArray())
+        );
     }
 
     public function testSpecifyingAnotherUrlHelperToGenerateHrefs()
@@ -481,6 +696,32 @@ class Zend_Navigation_Page_MvcTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($expected, $actual);
     }
 
+    /**
+     * @group ZF-7794
+     */
+    public function testSpecifyingAnotherSchemeHelperToGenerateHrefs()
+    {
+        $path = dirname(dirname(__FILE__)) . '/_files/My/SchemeHelper.php';
+        require_once $path;
+
+        $newHelper = new My_SchemeHelper();
+        Zend_Navigation_Page_Mvc::setSchemeHelper($newHelper);
+
+        $page = new Zend_Navigation_Page_Mvc(
+            array(
+                 'scheme' => 'https',
+            )
+        );
+
+        $expected = My_SchemeHelper::RETURN_URL;
+        $actual   = $page->getHref();
+
+        $old = new Zend_View_Helper_ServerUrl();
+        Zend_Navigation_Page_Mvc::setSchemeHelper($old);
+
+        $this->assertEquals($expected, $actual);
+    }
+
     /**
      * @group ZF-11550
      */
@@ -523,4 +764,115 @@ class Zend_Navigation_Page_MvcTest extends PHPUnit_Framework_TestCase
 
         $this->assertEquals(true, $page->isActive());
     }
+
+    /**
+     * @group ZF-12414
+     */
+    public function testNullValueInParameters()
+    {
+        // Create pages
+        $pages         = array();
+        $pages['home'] = new Zend_Navigation_Page_Mvc(
+            array(
+                 'label'      => 'Home',
+                 'route'      => 'page',
+                 'params'     => array(
+                     'slug' => '',
+                 ),
+            )
+        );
+        $pages['news'] = new Zend_Navigation_Page_Mvc(
+            array(
+                 'label'      => 'News',
+                 'route'      => 'page',
+                 'params'     => array(
+                     'slug' => 'news',
+                 ),
+            )
+        );
+
+        // Add route
+        $this->_front->getRouter()->addRoute(
+            'page',
+            new Zend_Controller_Router_Route_Regex(
+                '((?!(admin|page)).*)',
+                array(
+                    'module'     => 'page',
+                    'controller' => 'index',
+                    'action'     => 'index',
+                ),
+                array(
+                    1 => 'slug',
+                ),
+                '%s'
+            )
+        );
+
+        // Set request
+        $this->_front->getRequest()->setParams(
+            array(
+                 'module'     => 'page',
+                 'controller' => 'index',
+                 'action'     => 'index',
+                 'slug'       => 'news',
+            )
+        );
+
+        $this->assertTrue($pages['news']->isActive());
+        $this->assertFalse($pages['home']->isActive());
+    }
+
+    /**
+     * @group ZF-11442
+     */
+    public function testIsActiveIsChainedRouteAware()
+    {
+        // Create page
+        $page = new Zend_Navigation_Page_Mvc(
+            array(
+                 'action' => 'myaction',
+                 'route'  => 'myroute',
+                 'params' => array(
+                     'page' => 1337,
+                     'item' => 1234
+                 )
+            )
+        );
+
+        // Create chained route
+        $chain = new Zend_Controller_Router_Route_Chain();
+
+        $foo = new Zend_Controller_Router_Route(
+            'lolcat/:action',
+            array(
+                 'module'     => 'default',
+                 'controller' => 'foobar',
+                 'action'     => 'bazbat'
+            )
+        );
+        $bar = new Zend_Controller_Router_Route(
+            ':page/:item',
+            array(
+                 'page' => 1,
+                 'item' => 1
+            )
+        );
+        $chain->chain($foo)->chain($bar);
+
+        // Set up router
+        $this->_front->getRouter()->addRoute('myroute', $chain);
+
+        $this->_front->getRequest()->setParams(
+            array(
+                 'module'     => 'default',
+                 'controller' => 'foobar',
+                 'action'     => 'myaction',
+                 'page'       => 1337,
+                 'item'       => 1234
+            )
+        );
+
+        // Test
+        $this->assertTrue($page->isActive());
+    }
 }
