@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: WsdlTest.php 24601 2012-01-10 21:16:28Z ralph $
+ * @version    $Id: WsdlTest.php 24602 2012-01-12 22:10:13Z ralph $
  */
 
 /** Zend_Soap_Wsdl */
@@ -517,7 +517,7 @@ class Zend_Soap_WsdlTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('xsd:int',          $wsdl->getType('int'),     'xsd:int detection failed.');
         $this->assertEquals('xsd:int',          $wsdl->getType('integer'), 'xsd:int detection failed.');
         $this->assertEquals('xsd:float',        $wsdl->getType('float'),   'xsd:float detection failed.');
-        $this->assertEquals('xsd:float',        $wsdl->getType('double'),  'xsd:float detection failed.');
+        $this->assertEquals('xsd:double',       $wsdl->getType('double'),  'xsd:double detection failed.');
         $this->assertEquals('xsd:boolean',      $wsdl->getType('boolean'), 'xsd:boolean detection failed.');
         $this->assertEquals('xsd:boolean',      $wsdl->getType('bool'),    'xsd:boolean detection failed.');
         $this->assertEquals('soap-enc:Array',   $wsdl->getType('array'),   'soap-enc:Array detection failed.');
@@ -533,7 +533,7 @@ class Zend_Soap_WsdlTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($wsdl->getComplexTypeStrategy() instanceof Zend_Soap_Wsdl_Strategy_DefaultComplexType);
 
         $wsdl2 = new Zend_Soap_Wsdl('MyService', 'http://localhost/MyService.php', false);
-        $this->assertEquals('xsd:anyType',             $wsdl2->getType('Zend_Soap_Wsdl_Test'));
+        $this->assertEquals('xsd:anyType', $wsdl2->getType('Zend_Soap_Wsdl_Test'));
         $this->assertTrue($wsdl2->getComplexTypeStrategy() instanceof Zend_Soap_Wsdl_Strategy_AnyType);
     }
 
@@ -633,7 +633,7 @@ class Zend_Soap_WsdlTest extends PHPUnit_Framework_TestCase
         $this->assertEquals("xsd:int", $wsdl->getType("iNt"));
         $this->assertEquals("xsd:int", $wsdl->getType("INTEGER"));
         $this->assertEquals("xsd:float", $wsdl->getType("FLOAT"));
-        $this->assertEquals("xsd:float", $wsdl->getType("douBLE"));
+        $this->assertEquals("xsd:double", $wsdl->getType("douBLE"));
     }
 
     /**
