@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: HeadLinkTest.php 24594 2012-01-05 21:27:01Z matthew $
+ * @version    $Id: HeadLinkTest.php 24858 2012-06-01 01:24:17Z adamlundrigan $
  */
 
 // Call Zend_View_Helper_HeadLinkTest::main() if this source file is executed directly.
@@ -467,6 +467,35 @@ class Zend_View_Helper_HeadLinkTest extends PHPUnit_Framework_TestCase
         $this->helper->appendStylesheet(array('href' => '/bar/baz', 'id' => 'foo'));
         $this->assertContains('id="foo"', $this->helper->toString());
     }
+
+    /**
+     * @group ZF-11811
+     */
+    public function testHeadLinkAllowsOverrideOfRelAttribute()
+    {
+        $this->helper->appendStylesheet('/css/auth.less', 'all', null, array('rel' => 'stylesheet/less'));
+        $this->assertEquals(1, substr_count($this->helper->toString(), "rel=\""));
+        $this->assertContains('rel="stylesheet/less"', $this->helper->toString());
+    }
+
+    /**
+     * @group ZF-11643
+     */
+    public function testSizesAttributeIsSupported()
+    {
+        $this->helper->headLink(
+            array(
+                 'rel'   => 'icon',
+                 'href'  => 'favicon.png',
+                 'sizes' => '16x16',
+                 'type'  => 'image/png',
+            )
+        );
+
+        $expected = '<link href="favicon.png" rel="icon" type="image/png" sizes="16x16" >';
+
+        $this->assertEquals($expected, $this->helper->toString());
+    }
 }
 
 // Call Zend_View_Helper_HeadLinkTest::main() if this source file is executed directly.
